Unified protocol server lifecycle implementation Unified protocol server implementation for the gRPC mock server.
Structs
- Grpc
Mock Server - A
MockProtocolServerwrapper around the gRPC server startup.
Unified protocol server lifecycle implementation Unified protocol server implementation for the gRPC mock server.
MockProtocolServer wrapper around the gRPC server startup.